@@ -9,7 +9,9 @@ def source(conan_api, parser, *args):
     """
     Call the source() method.
     """
-    parser.add_argument("path", help="Path to a folder containing a conanfile.py")
+    parser.add_argument("path", help="Path to a folder containing a conanfile.py. "
+                                     "Defaults to current directory",
+                        default=".", nargs="?")
     add_reference_args(parser)
     args = parser.parse_args(*args)
 
